@@ -8,6 +8,7 @@
 
 
 
+
 #' @import dtplyr
 #' @import dplyr
 #' @import methods
@@ -92,6 +93,11 @@ arealSumPrep2 <- function(db, grpBy, polys, nCores){
   pltSF <- pltSF %>%
     st_transform(crs = st_crs(polys))
 
+  ## Crop the polygon to the bounding box of the FIA plots first
+  suppressWarnings({suppressMessages({
+    polys <- sf::st_crop(polys, st_bbox(pltSF))
+  })})
+
   ## Split up polys
   polyList <- split(polys, as.factor(polys$polyID))
   suppressWarnings({suppressMessages({
@@ -184,6 +190,33 @@ grpByToChar <- function(db, grpBy_quo){
     } else {
       grpBy <- NULL
     }
+  } else if ('SEEDLING' %in% names(db)) {
+    # Probably cheating, but it works
+    if (quo_name(grpBy_quo) != 'NULL'){
+      ## Have to join tables to run select with this object type
+      plt_quo <- filter(db$PLOT, !is.na(PLT_CN))
+      ## We want a unique error message here to tell us when columns are not present in data
+      d_quo <- tryCatch(
+        error = function(cnd) {
+          return(0)
+        },
+        plt_quo[10,] %>% # Just the first row
+          left_join(select(db$COND, PLT_CN, names(db$COND)[names(db$COND) %in% names(db$PLOT) == FALSE]), by = 'PLT_CN') %>%
+          inner_join(select(db$SEEDLING, PLT_CN, names(db$SEEDLING)[names(db$SEEDLING) %in% c(names(db$PLOT), names(db$COND)) == FALSE]), by = 'PLT_CN') %>%
+          select(!!grpBy_quo)
+      )
+
+      # If column doesnt exist, just returns 0, not a dataframe
+      if (is.null(nrow(d_quo))){
+        grpName <- quo_name(grpBy_quo)
+        stop(paste('Columns', grpName, 'not found in PLOT, SEEDLING, or COND tables. Did you accidentally quote the variables names? e.g. use grpBy = ECOSUBCD (correct) instead of grpBy = "ECOSUBCD". ', collapse = ', '))
+      } else {
+        # Convert to character
+        grpBy <- names(d_quo)
+      }
+    } else {
+      grpBy <- NULL
+    }
   } else {
     # Probably cheating, but it works
     if (quo_name(grpBy_quo) != 'NULL'){
@@ -844,7 +877,7 @@ filterAnnual <- function(x, grpBy, pltsVar, ESTN_UNIT) {
     group_by(STATECD, INVYR, .dots = grpBy[!c(grpBy %in% 'STATECD')]) %>%
     summarize(across(.cols = everything(), sum, na.rm = TRUE)) %>%
     ## Keep these
-    group_by(STATECD, INVYR) %>%
+    group_by(STATECD, INVYR, .dots = grpBy[!c(grpBy %in% 'STATECD')]) %>%
     mutate(keep = ifelse(INVYR %in% YEAR,
                          ifelse(YEAR == INVYR, 1, 0), ## When TRUE
                          ifelse(nplts == max(nplts, na.rm = TRUE), 1, 0))) %>% ## When INVYR not in YEAR, keep estimates from the inventory where panel has the most plots
